==> haskell-generic-lens-core-2.2.1.0-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-lens-core
version:              2.2.1.0
visibility:           public
id:                   generic-lens-core-2.2.1.0-KFFVheAYCuPBp3CIk0gi2Z
key:                  generic-lens-core-2.2.1.0-KFFVheAYCuPBp3CIk0gi2Z
license:              BSD-3-Clause
maintainer:           kiss.csongor.kiss@gmail.com
author:               Csongor Kiss
homepage:             https://github.com/kcsongor/generic-lens
synopsis:             Generically derive traversals, lenses and prisms.
description:
    This library uses GHC.Generics to derive efficient optics (traversals, lenses and prisms) for algebraic data types in a type-directed way, with a focus on good type inference and error messages when possible.

    This package is the shared internal logic of the
    @<https://hackage.haskell.org/package/generic-lens generic-lens>@
    and
    @<https://hackage.haskell.org/package/generic-optics generic-optics>@
    libraries.

category:             Generics, Records, Lens
abi:                  8993df19e7a48f7584d508dccfc4dc9d
exposed:              True
exposed-modules:
    Data.GenericLens.Internal Data.Generics.Internal.Errors
    Data.Generics.Internal.Families
    Data.Generics.Internal.Families.Changing
    Data.Generics.Internal.Families.Collect
    Data.Generics.Internal.Families.Has Data.Generics.Internal.GenericN
    Data.Generics.Internal.Profunctor.Iso
    Data.Generics.Internal.Profunctor.Lens
    Data.Generics.Internal.Profunctor.Prism
    Data.Generics.Internal.VL.Traversal Data.Generics.Internal.Void
    Data.Generics.Internal.Wrapped
    Data.Generics.Product.Internal.Fields
    Data.Generics.Product.Internal.GLens
    Data.Generics.Product.Internal.HList
    Data.Generics.Product.Internal.Param
    Data.Generics.Product.Internal.Positions
    Data.Generics.Product.Internal.Subtype
    Data.Generics.Product.Internal.Typed
    Data.Generics.Product.Internal.Types
    Data.Generics.Sum.Internal.Constructors
    Data.Generics.Sum.Internal.Subtype Data.Generics.Sum.Internal.Typed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-lens-core-2.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-lens-core-2.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-lens-core-2.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-lens-core
hs-libraries:         HSgeneric-lens-core-2.2.1.0-KFFVheAYCuPBp3CIk0gi2Z
depends:
    base-4.17.2.1 indexed-profunctors-0.1.1.1-22C7gA3HhCjKgNsu9Fnn18
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-generic-lens-core/html/generic-lens-core.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-lens-core-2.2.1.0-5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-lens-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-lens-core
version:              2.2.1.0
visibility:           public
id:                   generic-lens-core-2.2.1.0-nsF6f48Wo8AXiOzx8xZDo
key:                  generic-lens-core-2.2.1.0-nsF6f48Wo8AXiOzx8xZDo
license:              BSD-3-Clause
maintainer:           kiss.csongor.kiss@gmail.com
author:               Csongor Kiss
homepage:             https://github.com/kcsongor/generic-lens
synopsis:             Generically derive traversals, lenses and prisms.
description:
    This library uses GHC.Generics to derive efficient optics (traversals, lenses and prisms) for algebraic data types in a type-directed way, with a focus on good type inference and error messages when possible.

    This package is the shared internal logic of the
    @<https://hackage.haskell.org/package/generic-lens generic-lens>@
    and
    @<https://hackage.haskell.org/package/generic-optics generic-optics>@
    libraries.

category:             Generics, Records, Lens
abi:                  10aa3c448b4b7e0595059f912229570c
exposed:              True
exposed-modules:
    Data.GenericLens.Internal Data.Generics.Internal.Errors
    Data.Generics.Internal.Families
    Data.Generics.Internal.Families.Changing
    Data.Generics.Internal.Families.Collect
    Data.Generics.Internal.Families.Has Data.Generics.Internal.GenericN
    Data.Generics.Internal.Profunctor.Iso
    Data.Generics.Internal.Profunctor.Lens
    Data.Generics.Internal.Profunctor.Prism
    Data.Generics.Internal.VL.Traversal Data.Generics.Internal.Void
    Data.Generics.Internal.Wrapped
    Data.Generics.Product.Internal.Fields
    Data.Generics.Product.Internal.GLens
    Data.Generics.Product.Internal.HList
    Data.Generics.Product.Internal.Param
    Data.Generics.Product.Internal.Positions
    Data.Generics.Product.Internal.Subtype
    Data.Generics.Product.Internal.Typed
    Data.Generics.Product.Internal.Types
    Data.Generics.Sum.Internal.Constructors
    Data.Generics.Sum.Internal.Subtype Data.Generics.Sum.Internal.Typed

import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/generic-lens-core-2.2.1.0

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/generic-lens-core-2.2.1.0

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/generic-lens-core-2.2.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-lens-core
hs-libraries:         HSgeneric-lens-core-2.2.1.0-nsF6f48Wo8AXiOzx8xZDo
depends:
    base-4.18.3.0 indexed-profunctors-0.1.1.1-HrUOr9b7wbWDhnR5aolNmz
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-generic-lens-core/html/generic-lens-core.haddock

haddock-html:         /usr/share/doc/haskell-generic-lens-core/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
